@@ -1,11 +1,7 @@
-from .anyio_monkeypatch import apply_monkeypatch as _apply_anyio_monkeypatch
-
-_apply_anyio_monkeypatch()
-
-
 from purerpc.client import insecure_channel, secure_channel, Client
 from purerpc.server import Service, Servicer, Server
 from purerpc.rpc import Cardinality, RPCSignature, Stream
 from purerpc.grpclib.status import Status, StatusCode
 from purerpc.grpclib.exceptions import *
+from purerpc.utils import run
 from purerpc._version import __version__
