@@ -231,8 +231,12 @@ class GRPCSocket(AsyncExitStack):
 
     async def _listen(self):
         while True:
-            data = await self._socket.recv(self._receive_buffer_size)
-            if not data:
+            try:
+                data = await self._socket.recv(self._receive_buffer_size)
+            # TODO: Not too confident that BrokenResourceError should be treated
+            #  the same as EndOfStream (maybe the handler wants to know?), but it's
+            #  here for parity with anyio 1.x behavior.
+            except (anyio.EndOfStream, anyio.BrokenResourceError):
                 return
             events = self._grpc_connection.receive_data(data)
             await self._socket.flush()
